@@ -14,9 +14,9 @@ to standard output.
 try:
     # So many broken ctypeses out there.
     import ctypes
+    import struct
 except ImportError:
     ctypes = None
-import struct
 import sys
 import time
 
@@ -25,6 +25,8 @@ try:
 except ImportError:
     _uptime_posix = lambda: None
 
+__all__ = ['uptime']
+
 def _uptime_linux():
     """Returns uptime in seconds or None, on Linux."""
     # With procfs
@@ -69,6 +71,9 @@ def _uptime_beos():
     except:
         return None
 
+    if not hasattr(libroot, 'system_time'):
+        return None
+
     libroot.system_time.restype = ctypes.c_int64
     return libroot.system_time() / 1000000.
 
@@ -203,8 +208,6 @@ def _uptime_windows():
     Returns uptime in seconds or None, on Windows. Warning: may return
     incorrect answers after 49.7 days on versions older than Vista.
     """
-    if ctypes is None:
-        return None
     if not hasattr(ctypes, 'windll') or not hasattr(ctypes.windll, 'kernel32'):
         return None
     if hasattr(ctypes.windll.kernel32, 'GetTickCount64'):
